==> haskell-ghc-exactprint-0.6.3.3-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-exactprint
version:              0.6.3.3
visibility:           public
id:                   ghc-exactprint-0.6.3.3-EqD4wjBFo5FIkXa6QgkUey
key:                  ghc-exactprint-0.6.3.3-EqD4wjBFo5FIkXa6QgkUey
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 7.10.2, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    It does this with a phased approach

    * Delta - converts GHC API Annotations into relative
    offsets, indexed by SrcSpan

    * Transform - functions to facilitate changes to
    the AST, adjusting the annotations generated in the
    Delta phase to suit the changes.

    * Print - converts an AST and its annotations to
    properly formatted source text.

    * Pretty - adds annotations to an AST (fragment) so that
    the output can be parsed back to the same AST.


    Note: requires GHC 7.10.2 or later

category:             Development
abi:                  dcd85ecabd94f9e2ee2e796c7665814f
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Annotate
    Language.Haskell.GHC.ExactPrint.AnnotateTypes
    Language.Haskell.GHC.ExactPrint.Annotater
    Language.Haskell.GHC.ExactPrint.Delta
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Pretty
    Language.Haskell.GHC.ExactPrint.Print
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-8.10.3/site-local/ghc-exactprint-0.6.3.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/ghc-exactprint-0.6.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/ghc-exactprint-0.6.3.3
hs-libraries:         HSghc-exactprint-0.6.3.3-EqD4wjBFo5FIkXa6QgkUey
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1
    free-5.1.6-BE6pTLEn4SPBtuv643la9Y ghc-8.10.3 ghc-boot-8.10.3
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ mtl-2.2.2
    syb-0.7.1-EJn6avnnYqseQTf54r0Yp

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-ghc-exactprint-0.6.3.3-28-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-ghc-exactprint.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 ghc-exactprint
version:              0.6.3.3
visibility:           public
id:                   ghc-exactprint-0.6.3.3-KPS3RrLn1S4KoiJWKRIYtg
key:                  ghc-exactprint-0.6.3.3-KPS3RrLn1S4KoiJWKRIYtg
license:              BSD-3-Clause
maintainer:           alan.zimm@gmail.com
author:               Alan Zimmerman, Matthew Pickering
synopsis:             ExactPrint for GHC
description:
    Using the API Annotations available from GHC 7.10.2, this
    library provides a means to round trip any code that can
    be compiled by GHC, currently excluding lhs files.

    It does this with a phased approach

    * Delta - converts GHC API Annotations into relative
    offsets, indexed by SrcSpan

    * Transform - functions to facilitate changes to
    the AST, adjusting the annotations generated in the
    Delta phase to suit the changes.

    * Print - converts an AST and its annotations to
    properly formatted source text.

    * Pretty - adds annotations to an AST (fragment) so that
    the output can be parsed back to the same AST.


    Note: requires GHC 7.10.2 or later

category:             Development
abi:                  173147670190cee4d158f5a17b741cc5
exposed:              True
exposed-modules:
    Language.Haskell.GHC.ExactPrint
    Language.Haskell.GHC.ExactPrint.Annotate
    Language.Haskell.GHC.ExactPrint.AnnotateTypes
    Language.Haskell.GHC.ExactPrint.Annotater
    Language.Haskell.GHC.ExactPrint.Delta
    Language.Haskell.GHC.ExactPrint.Lookup
    Language.Haskell.GHC.ExactPrint.Parsers
    Language.Haskell.GHC.ExactPrint.Preprocess
    Language.Haskell.GHC.ExactPrint.Pretty
    Language.Haskell.GHC.ExactPrint.Print
    Language.Haskell.GHC.ExactPrint.Transform
    Language.Haskell.GHC.ExactPrint.Types
    Language.Haskell.GHC.ExactPrint.Utils

import-dirs:          /usr/lib/ghc-8.10.3/site-local/ghc-exactprint-0.6.3.3
library-dirs:         /usr/lib/ghc-8.10.3/site-local/ghc-exactprint-0.6.3.3
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/ghc-exactprint-0.6.3.3
hs-libraries:         HSghc-exactprint-0.6.3.3-KPS3RrLn1S4KoiJWKRIYtg
depends:
    base-4.14.1.0 bytestring-0.10.12.0 containers-0.6.2.1
    directory-1.3.6.0 filepath-1.4.2.1
    free-5.1.6-73r7Ag4NnqH1vQRYrsBZv6 ghc-8.10.3 ghc-boot-8.10.3
    ghc-paths-0.1.0.12-LgiNEBvorJD4Iq1vCUjVLQ mtl-2.2.2
    syb-0.7.2.1-IMisWBQ73CcBLtEce0DtDe

haddock-interfaces:
    /usr/share/doc/haskell-ghc-exactprint/html/ghc-exactprint.haddock

haddock-html:         /usr/share/doc/haskell-ghc-exactprint/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
